# Metadata


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**relations** | [**dict[str, RelationMetadata]**](RelationMetadata.md) |  | [optional] 
**module** | **str** |  | [optional] 
**source_info** | [**SourceInfo**](SourceInfo.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


